@@ -1,6 +1,6 @@
 package Module::Build::Tiny;
 {
-  $Module::Build::Tiny::VERSION = '0.027';
+  $Module::Build::Tiny::VERSION = '0.028';
 }
 use strict;
 use warnings;
@@ -14,19 +14,19 @@ use ExtUtils::Install qw/pm_to_blib install/;
 use ExtUtils::InstallPaths 0.002;
 use File::Basename qw/basename dirname/;
 use File::Find ();
-use File::Path qw/mkpath/;
+use File::Path qw/mkpath rmtree/;
 use File::Spec::Functions qw/catfile catdir rel2abs abs2rel splitdir/;
 use Getopt::Long qw/GetOptions/;
 use JSON::PP 2 qw/encode_json decode_json/;
 
 sub write_file {
-	my ($filename, $mode, $content) = @_;
-	open my $fh, ">:$mode", $filename or die "Could not open $filename: $!\n";;
+	my ($filename, $content) = @_;
+	open my $fh, '>', $filename or die "Could not open $filename: $!\n";
 	print $fh $content;
 }
 sub read_file {
 	my ($filename, $mode) = @_;
-	open my $fh, "<:$mode", $filename or die "Could not open $filename: $!\n";
+	open my $fh, '<', $filename or die "Could not open $filename: $!\n";
 	return do { local $/; <$fh> };
 }
 
@@ -53,9 +53,11 @@ sub process_xs {
 	my (undef, @dirnames) = splitdir(dirname($source));
 	my $file_base = basename($source, '.xs');
 	my $archdir = catdir(qw/blib arch auto/, @dirnames, $file_base);
+	my $tempdir = 'temp';
 
-	my $c_file = catfile('lib', @dirnames, "$file_base.c");
+	my $c_file = catfile($tempdir, "$file_base.c");
 	require ExtUtils::ParseXS;
+	mkpath($tempdir, $options->{verbose}, oct '755');
 	ExtUtils::ParseXS::process_file(filename => $source, prototypes => 0, output => $c_file);
 
 	my $version = $options->{meta}->version;
@@ -64,7 +66,7 @@ sub process_xs {
 	my $ob_file = $builder->compile(source => $c_file, defines => { VERSION => qq/"$version"/, XS_VERSION => qq/"$version"/ });
 
 	mkpath($archdir, $options->{verbose}, oct '755') unless -d $archdir;
-	return $builder->link(objects => $ob_file, lib_file => catfile($archdir, "$file_base.".$options->{config}->get('dlext')), module_name => join '::', @dirnames, $file_base);
+	return $builder->link(objects => $ob_file, lib_file => catfile($archdir, "$file_base." . $options->{config}->get('dlext')), module_name => join '::', @dirnames, $file_base);
 }
 
 sub find {
@@ -80,14 +82,16 @@ my %actions = (
 		system $^X, $_ and die "$_ returned $?\n" for find(qr/\.PL$/, 'lib');
 		my %modules = map { $_ => catfile('blib', $_) } find(qr/\.p(?:m|od)$/, 'lib');
 		my %scripts = map { $_ => catfile('blib', $_) } find(qr//, 'script');
-		my %shared =  map { $_ => catfile(qw/blib lib auto share dist/, $opt{meta}->name, abs2rel($_, 'share')) } find(qr//, 'share');
+		my %shared  = map { $_ => catfile(qw/blib lib auto share dist/, $opt{meta}->name, abs2rel($_, 'share')) } find(qr//, 'share');
 		pm_to_blib({ %modules, %scripts, %shared }, catdir(qw/blib lib auto/));
 		make_executable($_) for values %scripts;
 		mkpath(catdir(qw/blib arch/), $opt{verbose});
 		process_xs($_, \%opt) for find(qr/.xs$/, 'lib');
 
-		if ($opt{install_paths}->install_destination('libdoc') && $opt{install_paths}->is_default_installable('libdoc')) {
+		if ($opt{install_paths}->install_destination('bindoc') && $opt{install_paths}->is_default_installable('bindoc')) {
 			manify($_, catfile('blib', 'bindoc', man1_pagename($_)), $opt{config}->get('man1ext'), \%opt) for keys %scripts;
+		}
+		if ($opt{install_paths}->install_destination('libdoc') && $opt{install_paths}->is_default_installable('libdoc')) {
 			manify($_, catfile('blib', 'libdoc', man3_pagename($_)), $opt{config}->get('man3ext'), \%opt) for keys %modules;
 		}
 	},
@@ -95,7 +99,7 @@ my %actions = (
 		my %opt = @_;
 		die "Must run `./Build build` first\n" if not -d 'blib';
 		require TAP::Harness;
-		my $tester = TAP::Harness->new({verbosity => $opt{verbose}, lib => [ map { rel2abs(catdir(qw/blib/, $_)) } qw/arch lib/ ], color => -t STDOUT});
+		my $tester = TAP::Harness->new({ verbosity => $opt{verbose}, lib => [ map { rel2abs(catdir(qw/blib/, $_)) } qw/arch lib/ ], color => -t STDOUT });
 		$tester->runtests(sort +find(qr/\.t$/, 't'))->has_errors and exit 1;
 	},
 	install => sub {
@@ -103,15 +107,23 @@ my %actions = (
 		die "Must run `./Build build` first\n" if not -d 'blib';
 		install($opt{install_paths}->install_map, @opt{qw/verbose dry_run uninst/});
 	},
+	clean => sub {
+		my %opt = @_;
+		rmtree($_, $opt{verbose}) for qw/blib temp/;
+	},
+	realclean => sub {
+		my %opt = @_;
+		rmtree($_, $opt{verbose}) for qw/blib temp Build _build_params MYMETA.yml MYMETA.json/;
+	},
 );
 
 sub Build {
 	my $action = @ARGV && $ARGV[0] =~ /\A\w+\z/ ? shift @ARGV : 'build';
 	die "No such action '$action'\n" if not $actions{$action};
-	unshift @ARGV, @{ decode_json(read_file('_build_params', 'utf8')) };
+	unshift @ARGV, @{ decode_json(read_file('_build_params')) };
 	GetOptions(\my %opt, qw/install_base=s install_path=s% installdirs=s destdir=s prefix=s config=s% uninst:1 verbose:1 dry_run:1 pureperl-only:1 create_packlist=i/);
 	$_ = detildefy($_) for grep { defined } @opt{qw/install_base destdir prefix/}, values %{ $opt{install_path} };
-	@opt{'config', 'meta'} = (ExtUtils::Config->new($opt{config}), get_meta());
+	@opt{ 'config', 'meta' } = (ExtUtils::Config->new($opt{config}), get_meta());
 	$actions{$action}->(%opt, install_paths => ExtUtils::InstallPaths->new(%opt, dist_name => $opt{meta}->name));
 }
 
@@ -119,11 +131,11 @@ sub Build_PL {
 	my $meta = get_meta();
 	printf "Creating new 'Build' script for '%s' version '%s'\n", $meta->name, $meta->version;
 	my $dir = $meta->name eq 'Module-Build-Tiny' ? "use lib 'lib';" : '';
-	write_file('Build', 'raw', "#!perl\n$dir\nuse Module::Build::Tiny;\nBuild();\n");
+	write_file('Build', "#!perl\n$dir\nuse Module::Build::Tiny;\nBuild();\n");
 	make_executable('Build');
 	my @env = defined $ENV{PERL_MB_OPT} ? split_like_shell($ENV{PERL_MB_OPT}) : ();
-	write_file('_build_params', 'utf8', encode_json([ @env, @ARGV ]));
-	$meta->save(@$_) for ['MYMETA.json'], ['MYMETA.yml' => { version => 1.4 }];
+	write_file('_build_params', encode_json([ @env, @ARGV ]));
+	$meta->save(@$_) for ['MYMETA.json'], [ 'MYMETA.yml' => { version => 1.4 } ];
 }
 
 1;
@@ -143,7 +155,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
